#!/bin/sh

RRDTOOL=/usr/local/rrdtool-1.0.48/bin/rrdtool

$RRDTOOL create /etc/postfix/mailqueues.rrd --step 60 \
	DS:active:GAUGE:900:0:U \
	DS:deferred:GAUGE:900:0:U \
	RRA:AVERAGE:0.5:1:20160 \
	RRA:AVERAGE:0.5:30:2016 \
	RRA:AVERAGE:0.5:60:105120 \
	RRA:MAX:0.5:1:1440 \
	RRA:MAX:0.5:30:2016 \
	RRA:MAX:0.5:60:105120
